@@ -655,7 +655,7 @@ void Application::slotAccountStateAdded(AccountState *accountState)
     connect(accountState->account().data(), &Account::serverVersionChanged,
         _folderManager.data(), &FolderMan::slotServerVersionChanged);
 
-    _gui->slotTrayMessageIfServerUnsupported(accountState->account().data());
+    _gui->slotTrayMessageIfServerUnsupported(accountState->account());
 }
 
 void Application::slotCleanup()
@@ -1003,8 +1003,10 @@ QString substLang(const QString &lang)
 
 void Application::setupTranslations()
 {
+    qCInfo(lcApplication) << "System UI languages are:" << QLocale::system().uiLanguages();
     const auto enforcedLocale = Theme::instance()->enforcedLocale();
     const auto lang = substLang(!enforcedLocale.isEmpty() ? enforcedLocale : QLocale::system().uiLanguages(QLocale::TagSeparator::Underscore).first());
+    qCInfo(lcApplication) << "selected application language:" << lang;
 
     auto *translator = new QTranslator(this);
     auto *qtTranslator = new QTranslator(this);
