@@ -77,10 +77,10 @@ private:
     QString _pollToken;
     QString _pollEndpoint;
     QTimer _pollTimer;
-    qint64 _secondsLeft;
-    qint64 _secondsInterval;
-    bool _isBusy;
-    bool _hasToken;
+    qint64 _secondsLeft = 0LL;
+    qint64 _secondsInterval = 0LL;
+    bool _isBusy = false;
+    bool _hasToken = false;
     bool _enforceHttps = false;
 };
 
