@@ -29,7 +29,10 @@ class FolderCreationDialog : public QDialog
 
 public:
     explicit FolderCreationDialog(const QString &destination, QWidget *parent = nullptr);
-    ~FolderCreationDialog();
+    ~FolderCreationDialog() override;
+
+signals:
+    void folderCreated(const QString &fullFolderPath);
 
 private slots:
     void accept() override;
