@@ -21,6 +21,7 @@
 #include <QVector>
 #include <QElapsedTimer>
 #include <QPointer>
+#include <QFileIconProvider>
 
 class QNetworkReply;
 namespace OCC {
@@ -161,6 +162,8 @@ private:
      */
     QMap<QPersistentModelIndex, QElapsedTimer> _fetchingItems;
 
+    QFileIconProvider _fileIconProvider;
+
 signals:
     void dirtyChanged();
 
