@@ -162,7 +162,7 @@ void FileProviderSocketController::requestFileProviderDomainInfo() const
     sendMessage(requestMessage);
 }
 
-void FileProviderSocketController::slotAccountStateChanged(const AccountState::State state)
+void FileProviderSocketController::slotAccountStateChanged(const AccountState::State state) const
 {
     switch(state) {
     case AccountState::Disconnected:
@@ -206,7 +206,10 @@ void FileProviderSocketController::sendNotAuthenticated() const
 
 void FileProviderSocketController::sendAccountDetails() const
 {
-    Q_ASSERT(_accountState);
+    if (!_accountState) {
+        qCWarning(lcFileProviderSocketController) << "No account state available to send account details, stopping";
+        return;
+    }
     const auto account = _accountState->account();
     Q_ASSERT(account);
 
@@ -241,7 +244,7 @@ void FileProviderSocketController::sendAccountDetails() const
     sendMessage(message);
 }
 
-void FileProviderSocketController::reportSyncState(const QString &receivedState)
+void FileProviderSocketController::reportSyncState(const QString &receivedState) const
 {
     if (!accountState()) {
         qCWarning(lcFileProviderSocketController) << "No account state available to report sync state";
