@@ -264,7 +264,7 @@ void ownCloudGui::slotOpenPath(const QString &path)
     showInFileManager(path);
 }
 
-void ownCloudGui::slotTrayMessageIfServerUnsupported(Account *account)
+void ownCloudGui::slotTrayMessageIfServerUnsupported(const AccountPtr &account)
 {
     if (account->serverVersionUnsupported()) {
         slotShowTrayMessage(
@@ -276,8 +276,8 @@ void ownCloudGui::slotTrayMessageIfServerUnsupported(Account *account)
     }
 }
 
-void ownCloudGui::slotNeedToAcceptTermsOfService(OCC::AccountPtr account,
-                                                 AccountState::State state)
+void ownCloudGui::slotNeedToAcceptTermsOfService(const OCC::AccountPtr &account,
+                                                 const OCC::AccountState::State state)
 {
     if (state == AccountState::NeedToSignTermsOfService) {
         slotShowTrayMessage(
