@@ -35,6 +35,7 @@ class SyncStatusSummary : public QObject
     Q_PROPERTY(bool syncing READ syncing NOTIFY syncingChanged)
     Q_PROPERTY(QString syncStatusString READ syncStatusString NOTIFY syncStatusStringChanged)
     Q_PROPERTY(QString syncStatusDetailString READ syncStatusDetailString NOTIFY syncStatusDetailStringChanged)
+    Q_PROPERTY(qint64 totalFiles READ totalFiles NOTIFY totalFilesChanged)
 
 public:
     explicit SyncStatusSummary(QObject *parent = nullptr);
@@ -44,6 +45,7 @@ public:
     [[nodiscard]] bool syncing() const;
     [[nodiscard]] QString syncStatusString() const;
     [[nodiscard]] QString syncStatusDetailString() const;
+    [[nodiscard]] qint64 totalFiles() const;
 
 signals:
     void syncProgressChanged();
@@ -51,6 +53,7 @@ signals:
     void syncingChanged();
     void syncStatusStringChanged();
     void syncStatusDetailStringChanged();
+    void totalFilesChanged();
 
 public slots:
     void load();
@@ -79,6 +82,7 @@ private:
     void setSyncStatusDetailString(const QString &value);
     void setSyncIcon(const QUrl &value);
     void setAccountState(AccountStatePtr accountState);
+    void setTotalFiles(const qint64 value);
 
     AccountStatePtr _accountState;
     std::set<QString> _foldersWithErrors;
@@ -86,6 +90,7 @@ private:
     QUrl _syncIcon = Theme::instance()->syncStatusOk();
     double _progress = 1.0;
     bool _isSyncing = false;
+    qint64 _totalFiles = 0;
     QString _syncStatusString = tr("All synced!");
     QString _syncStatusDetailString;
 };
