@@ -16,6 +16,8 @@
 #ifndef MIRALL_OWNCLOUD_WIZARD_COMMON_H
 #define MIRALL_OWNCLOUD_WIZARD_COMMON_H
 
+#include "config.h"
+
 #include <QString>
 
 class QVariant;
@@ -48,6 +50,7 @@ namespace WizardCommon {
 #ifdef WITH_WEBENGINE
         Page_WebView,
 #endif // WITH_WEBENGINE
+        Page_TermsOfService,
         Page_AdvancedSetup,
     };
 
