@@ -36,11 +36,12 @@ AccessManager::AccessManager(QObject *parent)
     : QNetworkAccessManager(parent)
 {
     setCookieJar(new CookieJar);
-    connect(this, &QNetworkAccessManager::authenticationRequired, this, [this](QNetworkReply *reply, QAuthenticator *authenticator) {
+    connect(this, &QNetworkAccessManager::authenticationRequired, this, [](QNetworkReply *reply, QAuthenticator *authenticator) {
+        Q_UNUSED(reply)
+
         if (authenticator->user().isEmpty()) {
-            qCWarning(lcAccessManager) << "Server requested authentication and we didn't provide a user, aborting ...";
+            qCWarning(lcAccessManager) << "Server requested authentication and we didn't provide a user";
             authenticator->setUser(QUuid::createUuid().toString());
-            reply->abort();
         }
     });
 }
