@@ -71,6 +71,7 @@ struct RemoteInfo
     bool _isE2eEncrypted = false;
     bool isFileDropDetected = false;
     QString e2eMangledName;
+    QByteArray e2eCertificateFingerprint;
     bool sharedByMe = false;
 
     [[nodiscard]] bool isValid() const { return !name.isNull(); }
@@ -86,6 +87,10 @@ struct RemoteInfo
     QString lockEditorApp;
     qint64 lockTime = 0;
     qint64 lockTimeout = 0;
+    QString lockToken;
+
+    bool isLivePhoto = false;
+    QString livePhotoFile;
 };
 
 struct LocalInfo
@@ -102,6 +107,7 @@ struct LocalInfo
     bool isVirtualFile = false;
     bool isSymLink = false;
     bool isMetadataMissing = false;
+    bool isPermissionsInvalid = false;
     [[nodiscard]] bool isValid() const { return !name.isNull(); }
 };
 
@@ -157,6 +163,7 @@ public:
     void abort();
     [[nodiscard]] bool isFileDropDetected() const;
     [[nodiscard]] bool encryptedMetadataNeedUpdate() const;
+    [[nodiscard]] QByteArray certificateSha256Fingerprint() const;
     [[nodiscard]] SyncFileItem::EncryptionStatus currentEncryptionStatus() const;
     [[nodiscard]] SyncFileItem::EncryptionStatus requiredEncryptionStatus() const;
 
@@ -197,6 +204,8 @@ private:
     bool _isFileDropDetected = false;
     bool _encryptedMetadataNeedUpdate = false;
     SyncFileItem::EncryptionStatus _encryptionStatusRequired = SyncFileItem::EncryptionStatus::NotEncrypted;
+    QByteArray _e2eCertificateFingerprint;
+
     // If set, the discovery will finish with an error
     int64_t _size = 0;
     QString _error;
@@ -306,6 +315,11 @@ class DiscoveryPhase : public QObject
 
     void enqueueDirectoryToDelete(const QString &path, ProcessDirectoryJob* const directoryJob);
 
+    /// contains files/folder names that are requested to be deleted permanently
+    QSet<QString> _permanentDeletionRequests;
+
+    void markPermanentDeletionRequests();
+
 public:
     // input
     QString _localDir; // absolute path to the local directory. ends with '/'
@@ -317,6 +331,7 @@ public:
     QRegularExpression _invalidFilenameRx; // FIXME: maybe move in ExcludedFiles
     QStringList _serverBlacklistedFiles; // The blacklist from the capabilities
     QStringList _leadingAndTrailingSpacesFilesAllowed;
+    bool _shouldEnforceWindowsFileNameCompatibility = false;
     bool _ignoreHiddenFiles = false;
     std::function<bool(const QString &)> _shouldDiscoverLocaly;
 
@@ -333,6 +348,11 @@ public:
 
     QStringList _listExclusiveFiles;
 
+    QStringList _forbiddenFilenames;
+    QStringList _forbiddenBasenames;
+    QStringList _forbiddenExtensions;
+    QStringList _forbiddenChars;
+
     bool _hasUploadErrorItems = false;
     bool _hasDownloadRemovedItems = false;
 
@@ -357,6 +377,7 @@ signals:
 
     void addErrorToGui(const SyncFileItem::Status status, const QString &errorMessage, const QString &subject, const OCC::ErrorCategory category);
 
+    void remnantReadOnlyFolderDiscovered(const OCC::SyncFileItemPtr &item);
 private slots:
     void slotItemDiscovered(const OCC::SyncFileItemPtr &item);
 };
