@@ -72,6 +72,8 @@ void EncryptFolderJob::slotEncryptionFlagSuccess(const QByteArray &fileId)
     if (!rec.isValid()) {
         if (_propagator && _item) {
             qCWarning(lcEncryptFolderJob) << "No valid record found in local DB for fileId" << fileId << "going to create it now...";
+            _item->_e2eEncryptionStatus = EncryptionStatusEnums::ItemEncryptionStatus::EncryptedMigratedV2_0;
+            _item->_e2eCertificateFingerprint = _account->e2e()->certificateSha256Fingerprint();
             const auto updateResult = _propagator->updateMetadata(*_item.data());
             if (updateResult) {
                 [[maybe_unused]] const auto result = _journal->getFileRecord(currentPath, &rec);
@@ -81,7 +83,7 @@ void EncryptFolderJob::slotEncryptionFlagSuccess(const QByteArray &fileId)
         }
     }
 
-    if (!rec.isE2eEncrypted()) {
+    if (rec.isValid() && !rec.isE2eEncrypted()) {
         rec._e2eEncryptionStatus = SyncJournalFileRecord::EncryptionStatus::Encrypted;
         rec._e2eCertificateFingerprint = _account->e2e()->certificateSha256Fingerprint();
         const auto result = _journal->setFileRecord(rec);
