@@ -15,7 +15,6 @@
 #include "clientsideencryption.h"
 
 namespace OCC {
-class FolderMetadata;
 
   /* This class is used if the server supports end to end encryption.
  * It will fire for *any* folder, encrypted or not, because when the
@@ -29,6 +28,8 @@ class FolderMetadata;
  *
  */
 
+class EncryptedFolderMetadataHandler;
+
 class PropagateUploadEncrypted : public QObject
 {
   Q_OBJECT
@@ -40,20 +41,13 @@ public:
 
     void unlockFolder();
 
-    [[nodiscard]] bool isUnlockRunning() const { return _isUnlockRunning; }
-    [[nodiscard]] bool isFolderLocked() const { return _isFolderLocked; }
-    [[nodiscard]] const QByteArray folderToken() const { return _folderToken; }
+    [[nodiscard]] bool isUnlockRunning() const;
+    [[nodiscard]] bool isFolderLocked() const;
+    [[nodiscard]] const QByteArray folderToken() const;
 
 private slots:
-    void slotFolderEncryptedIdReceived(const QStringList &list);
-    void slotFolderEncryptedIdError(QNetworkReply *r);
-    void slotFolderLockedSuccessfully(const QByteArray& fileId, const QByteArray& token);
-    void slotFolderLockedError(const QByteArray& fileId, int httpErrorCode);
-    void slotTryLock(const QByteArray& fileId);
-    void slotFolderEncryptedMetadataReceived(const QJsonDocument &json, int statusCode);
-    void slotFolderEncryptedMetadataError(const QByteArray& fileId, int httpReturnCode);
-    void slotUpdateMetadataSuccess(const QByteArray& fileId);
-    void slotUpdateMetadataError(const QByteArray& fileId, int httpReturnCode);
+    void slotFetchMetadataJobFinished(int statusCode, const QString &message);
+    void slotUploadMetadataFinished(int statusCode, const QString &message);
 
 signals:
     // Emitted after the file is encrypted and everything is setup.
@@ -66,9 +60,6 @@ private:
   QString _remoteParentPath;
   SyncFileItemPtr _item;
 
-  QByteArray _folderToken;
-  QByteArray _folderId;
-
   QElapsedTimer _folderLockFirstTry;
   bool _currentLockingInProgress = false;
 
@@ -77,9 +68,10 @@ private:
 
   QByteArray _generatedKey;
   QByteArray _generatedIv;
-  QScopedPointer<FolderMetadata> _metadata;
-  EncryptedFile _encryptedFile;
   QString _completeFileName;
+  QString _remoteParentAbsolutePath;
+
+  QScopedPointer<EncryptedFolderMetadataHandler> _encryptedFolderMetadataHandler;
 };
 
 
