@@ -21,6 +21,14 @@ class TestNextcloudPropagator : public QObject
     Q_OBJECT
 
 private slots:
+    void initTestCase()
+    {
+        OCC::Logger::instance()->setLogFlush(true);
+        OCC::Logger::instance()->setLogDebug(true);
+
+        QStandardPaths::setTestModeEnabled(true);
+    }
+
     void testUpdateErrorFromSession()
     {
         //OwncloudPropagator propagator(nullptr, QLatin1String("test1"), QLatin1String("test2"), new ProgressDatabase);
@@ -73,7 +81,7 @@ private slots:
         tests.append(Test("\"fii\"-gzip", "fii"));
         tests.append(Test("W/\"foo\"", "foo"));
 
-        foreach (const auto& test, tests) {
+        for (const auto &test : tests) {
             QCOMPARE(parseEtag(test.first), QByteArray(test.second));
         }
     }
